searchNodes=[{"doc":"Send a message to the BEAM from a shell script","ref":"BEAMNotify.html","title":"BEAMNotify","type":"module"},{"doc":"Return the path to beam_notify","ref":"BEAMNotify.html#bin_path/0","title":"BEAMNotify.bin_path/0","type":"function"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"BEAMNotify.html#child_spec/1","title":"BEAMNotify.child_spec/1","type":"function"},{"doc":"Return the OS environment needed to call $BEAM_NOTIFY This returns a map that can be passed directly to System.cmd/3 via its :env option. This function can be passed different things based on what's convenient. If you're setting up child_spec 's for a supervision tree and need the environment to pass in another child_spec , call this with the same options that you'd pass to start_link/1 . This is a very common use. If you called start_link/1 manually and have the pid, call it with the pid. If you only have the name that was passed to start_link/1 , then call it with the name. The name alone is insufficient for returning the $BEAM_NOTIFY_OPTIONS environment variable, so the BEAMNotify GenServer must be running. If you're in a chicken-and-egg situation where you're setting up a supervision tree, but it hasn't been started yet, see option 1.","ref":"BEAMNotify.html#env/1","title":"BEAMNotify.env/1","type":"function"},{"doc":"Start the BEAMNotify message receiver","ref":"BEAMNotify.html#start_link/1","title":"BEAMNotify.start_link/1","type":"function"},{"doc":"Callback for dispatching notifications BEAMNotify calls the dispatcher function whenever a message comes in. The first parameter is the list of arguments passed to $BEAM_NOTIFY . The second argument is a map containing environment variables. Whether or not the map is populated depends on the options to start_link/1 .","ref":"BEAMNotify.html#t:dispatcher/0","title":"BEAMNotify.dispatcher/0","type":"type"},{"doc":"BEAMNotify takes the following options :name - a unique name for this notifier. This is required if you expect to run multiple BEAMNotify GenServers at a time. :dispatcher - a function to call when a notification comes in :path - the path to use for the named socket. A path in the system temporary directory is the default. :report_env - set to true to report environment variables in addition to commandline argument. Defaults to false :recbuf - receive buffer size. If you're sending a particular large amount of data and getting errors from :erlang.binary_to_term(data) , try making this bigger. Defaults to 8192.","ref":"BEAMNotify.html#t:options/0","title":"BEAMNotify.options/0","type":"type"},{"doc":"BEAMNotify Send a message to the BEAM from a shell script This is one solution sending notifications from non-BEAM programs into Elixir. BEAMNotify lets you set up a GenServer that listens for notifications from shell scripts or anything that can invoke an OS process. Communication is via a Unix Domain socket. Messages are limited to strings that passed via commandline arguments or the environment to the beam_notify binary. There are, of course, other ways of solving this problem. Some non-Elixir programs already expose Unix domain or TCP socket interfaces for communication. This might be a better choice. You could also use erl_call or write a C node and communicate over distributed Erlang.","ref":"readme.html","title":"BEAMNotify","type":"extras"},{"doc":"BEAMNotify would typically be added to a supervision tree in your program. Options to BEAMNotify specify things like its name, a dispatch function to call, and other things. The shell script (or any program) needs to call the beam_notify program supplied by this library. The message is passed via commandline arguments or environment variables (see :report_env option). Since beam_notify needs to know how to connect to the appropriate BEAMNotify GenServer (there may be more than one), the shell script must pass some options. To make this easy, BEAMNotify provides two environment variables by calling BEAMNotify.env/1 : $BEAM_NOTIFY - the absolute path to the beam_notify executable $BEAM_NOTIFY_OPTIONS - how beam_notify should connect In the shell script, run $BEAM_NOTIFY and pass it any arguments that you want send up. BEAMNotify reports environment variables too. If it is not possible to pass the $BEAM_NOTIFY* environment variables through to your script due to a restricted shell environment, see the restricted shell section below. Back in Elixir, whenever a proper message is received, BEAMNotify will call the dispatch function. The dispatch function is responsible for forwarding on messages however makes sense in your application. If handling is simple, you can process them in the dispatch function. You could also publish them through Phoenix.PubSub or another pubsub service. BEAMNotify only handles strings, so if you want to be fancier with your messages or filter them, you'll have to add that to your dispatcher function. It is important to keep in mind that the amount of data that can be sent in a notification is limited by the transport and by OS limits on commandline arguments. Suffice it to say that this is not intended for file transfer.","ref":"readme.html#overview","title":"BEAMNotify - Overview","type":"extras"},{"doc":"What we're going to do is create a script that sends a message to Elixir. First, make sure that you have :beam_notify by either cloning this project or creating a test Elixir project ( mix new ... ) and adding it to the mix.exs : def deps do [ { :beam_notify , &quot;~&gt; 0.2.0&quot; } ] end Now open an editor and create simple.sh with the following contents: #!/bin/sh echo &quot;This is simple.sh&quot; $BEAM_NOTIFY Hello world Start up Elixir with iex -S mix : # Get the PID that&#39;s running the IEx console iex&gt; us = self ( ) # PID &lt; 0 . 204 . 0 &gt; # Start a BEAMNotify GenServer. The dispatcher function sends a tuple with the # arguments and environment passed in from the shell script. iex&gt; BEAMNotify . start_link ( name : &quot;sulu&quot; , report_env : true , dispatcher : &amp; send ( us , { &amp;1 , &amp;2 } ) ) { :ok , # PID &lt; 0 . 211 . 0 &gt; } # Run the shell script. We&#39;re doing this from Elixir, but you # can also grab the environment by calling `BEAMNotify.env/1` and run it # in another terminal window. iex&gt; System . cmd ( &quot;/bin/sh&quot; , [ &quot;simple.sh&quot; ] , env : BEAMNotify . env ( &quot;sulu&quot; ) ) { &quot;This is simple.sh \\n &quot; , 0 } # See what was sent iex&gt; flush { [ &quot;Hello&quot; , &quot;world&quot; ] , %{ ... } }","ref":"readme.html#example","title":"BEAMNotify - Example","type":"extras"},{"doc":"Here's a code snippet of starting a hypothetical non-Elixir program that needs to send messages back to Elixir. This code is part of a module-based supervisor , but this isn't necessary. Two GenServers are started: one for BEAMNotify and one to start and monitor the non-Elixir program using MuonTrap.Daemon . Note how BEAMNotify.env/1 is used to pass the proper environment to the program. @impl Supervisor def init ( _ ) do beam_notify_options = [ name : &quot;my_beam&quot; , dispatcher : &amp; Some . function / 2 ] children = [ { BEAMNotify , beam_notify_options } , { MuonTrap.Daemon , [ &quot;/path/to/program&quot; , [ &quot;-s&quot; , &quot;script_calling_beam_notify.sh&quot; ] , [ log_output : :debug , env : BEAMNotify . env ( beam_notify_options ) ] ] } ] opts = [ strategy : :one_for_one ] Supervisor . start_link ( children , opts ) end If you're lucky, it might be sufficient to call BEAMNotify.bin_path/0 to get the path to the beam_notify program and pass that directly to the non-Elixir program. You'll still need to set the environment for beam_notify to work. On the bright side, this will skip out having your system start bash on each notification.","ref":"readme.html#supervision-example","title":"BEAMNotify - Supervision example","type":"extras"},{"doc":"Some programs clear the OS environment before running programs as a security precaution. It's still possible send messages to Elixir. You'll need to know the path to the beam_notify binary and have a place to put the communications socket that both Elixir and the beam_notify binary can open. In this example, the socket will be created as /tmp/my_beam_notify_socket . In Elixir, the BEAMNotify child_spec might look like this: { BEAMNotify , name : &quot;any name&quot; , path : &quot;/tmp/my_beam_notify_socket&quot; , dispatcher : &amp; Some . function / 2 } For the script, here's a sample for Nerves devices where code is installed under /srv/erlang . #!/bin/sh BEAM_NOTIFY=$(ls /srv/erlang/lib/beam_notify-*/priv/beam_notify) $BEAM_NOTIFY -p /tmp/my_beam_notify_socket -- hello The arguments following the -- are passed. The -p /tmp/my_beam_notify_socket part will be dropped. Arguments are only parsed (and dropped) if $BEAM_NOTIFY_OPTIONS isn't defined. In other words, $BEAM_NOTIFY_OPTIONS takes precedence.","ref":"readme.html#restricted-shell-environments","title":"BEAMNotify - Restricted shell environments","type":"extras"},{"doc":"This library is covered by the Apache 2 license.","ref":"readme.html#license","title":"BEAMNotify - License","type":"extras"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This release only cleans up Makefile prints and bumps dependencies. No code changes were made.","ref":"changelog.html#v0-2-1","title":"Changelog - v0.2.1","type":"extras"},{"doc":"New features Support for explicitly passing the socket path - this enables use in restricted environments where it's impossible or hard to pass parameters through environment variables Reporting the environment is off by default. See the :report_env option Default socket paths are obfuscated. This also removes OS-specific character-set issues and length limitations","ref":"changelog.html#v0-2-0","title":"Changelog - v0.2.0","type":"extras"},{"doc":"Initial release to hex.","ref":"changelog.html#v0-1-0","title":"Changelog - v0.1.0","type":"extras"}]